@@ -37,6 +37,7 @@ _SUPPORTED_USERS['aodh']='aodh 42402 42402 /var/lib/aodh kolla'
 _SUPPORTED_USERS['barbican']='barbican 42403 42403 /var/lib/barbican kolla,nfast'
 _SUPPORTED_USERS['ceilometer']='ceilometer 42405 42405 /var/lib/ceilometer kolla'
 _SUPPORTED_USERS['cinder']='cinder 42407 42407 /var/lib/cinder kolla'
+_SUPPORTED_USERS['cloud-admin']='cloud-admin 42401 42401 /home/cloud-admin'
 _SUPPORTED_USERS['collectd']='collectd 42409 42409 /var/lib/collectd kolla'
 _SUPPORTED_USERS['designate']='designate 42411 42411 /var/lib/designate kolla'
 _SUPPORTED_USERS['etcd']='etcd 42413 42413 /var/lib/etcd kolla'
@@ -68,6 +69,7 @@ _SUPPORTED_USERS['rabbitmq']='rabbitmq 42439 42439 /var/lib/rabbitmq kolla'
 _SUPPORTED_USERS['redis']='redis 42460 42460 /run/redis kolla'
 _SUPPORTED_USERS['swift']='swift 42445 42445 /var/lib/swift kolla'
 _SUPPORTED_USERS['tempest']='tempest 42480 42480 /var/lib/tempest kolla'
+_SUPPORTED_USERS['tss']='tss 42485 42485 /var/lib/tpm kolla'
 _SUPPORTED_USERS['zaqar']='zaqar 42452 42452 /var/lib/zaqar kolla'
 
 for _USER_TO_CREATE in $_USERS_TO_CREATE; do
