@@ -159,6 +159,7 @@ DO_NOT_ROTATE_LIST = (
     'CephClusterFSID',
     'CephManilaClientKey',
     'CephRgwKey',
+    'HeatAuthEncryptionKey',
 )
 
 PLAN_NAME_PATTERN = '^[a-zA-Z0-9-]+$'
@@ -186,16 +187,9 @@ USER_ENVIRONMENT = 'user-environment.yaml'
 CONTAINER_DEFAULTS_ENVIRONMENT = ('environments/'
                                   'containers-default-parameters.yaml')
 
-DEFAULT_DEPLOY_KERNEL_NAME = 'bm-deploy-kernel'
-
-DEFAULT_DEPLOY_RAMDISK_NAME = 'bm-deploy-ramdisk'
-
 # The name for the swift container to host the cache for tripleo
 TRIPLEO_CACHE_CONTAINER = "__cache__"
 
-TRIPLEO_UI_LOG_FILE_SIZE = 1e7  # 10MB
-TRIPLEO_UI_LOG_FILENAME = 'tripleo-ui.logs'
-
 API_NETWORK = 'InternalApi'
 LEGACY_API_NETWORK = 'Internal'
 
@@ -205,9 +199,6 @@ NESTED_DEPTH = 7
 # Resource name for deployment resources when using config download
 TRIPLEO_DEPLOYMENT_RESOURCE = 'TripleODeployment'
 
-# Resource name for network config resources when using config download
-TRIPLEO_NETWORK_CONFIG_RESOURCE = 'NetworkConfig'
-
 HOST_NETWORK = 'ctlplane'
 
 # The key is different in RoleConfig than in RoleData, so we need both so they
@@ -216,8 +207,6 @@ EXTERNAL_TASKS = ['external_deploy_tasks', 'external_deploy_steps_tasks']
 
 ANSIBLE_ERRORS_FILE = 'ansible-errors.json'
 
-DEPLOYMENT_STATUS_FILE = 'deployment_status.yaml'
-
 MISTRAL_WORK_DIR = '/var/lib/mistral'
 
 EXCLUSIVE_NEUTRON_DRIVERS = ['ovn', 'openvswitch']
